@@ -59,7 +59,7 @@
 #define ISO_DISC_LABEL_SIZE 129
 
 
-/* The maximum lenght of an specs violating ECMA-119 file identifier.
+/* The maximum length of an specs violating ECMA-119 file identifier.
    The theoretical limit is  254 - 34 - 28 (len of SUSP CE entry) = 192
    Currently the practical limit is 254 - 34 - 96 (non-CE RR entries) - 28 (CE)
 */
@@ -223,7 +223,7 @@ struct iso_write_opts {
     /**
      * Write AAIP as extension according to SUSP 1.10 rather than SUSP 1.12.
      * I.e. without announcing it by an ER field and thus without the need
-     * to preceed the RRIP fields by an ES and to preceed the AA field by ES.
+     * to precede the RRIP fields by an ES and to precede the AA field by ES.
      * This saves bytes and might avoid problems with readers which dislike
      * ER fields other than the ones for RRIP.
      * On the other hand, SUSP 1.12 frowns on such unannounced extensions
@@ -487,6 +487,15 @@ struct iso_write_opts {
      */
     int appended_as_gpt;
 
+    /* If 1: With appended partitions: mark by APM partition
+     */
+    int appended_as_apm;
+
+    /* If 1: Obey struct el_torito_boot_image.isolinux_options bit2-7 and bit8.
+             I.e. mention boot image as partition in GPT and/or APM.
+     */
+    int part_like_isohybrid;
+
     /* Eventual name of the non-ISO aspect of the image. E.g. SUN ASCII label.
      */
     char ascii_disc_label[ISO_DISC_LABEL_SIZE];
@@ -504,6 +513,13 @@ struct iso_write_opts {
      */
     int apm_block_size;
 
+    /* User defined GUID for GPT header and base of reproducible partition
+       GUIDs. (Not to be confused with volume "UUID", which is actually a
+       timestamp.)
+       See API call iso_write_opts_set_gpt_guid().
+     */
+    uint8_t gpt_disk_guid[16];
+    int gpt_disk_guid_mode;
 };
 
 typedef struct ecma119_image Ecma119Image;
@@ -554,10 +570,19 @@ struct ecma119_image
 
     time_t now; /**< Time at which writing began. */
 
-    /** Total size of the output. This only includes the current volume. */
+    /* Total size of the output. Counted in bytes.
+     * Includes ISO filesystem and appended data.
+     */
     off_t total_size;
+
+    /** Size actually governed by the ISO filesystem part of the output */
     uint32_t vol_space_size;
 
+    /* 1= write the total size into the PVD of the ISO,
+     * 0= write vol_space_size
+     */
+    int pvd_size_is_total_size;
+
     /* Bytes already written to image output */
     off_t bytes_written;
     /* just for progress notification */
@@ -640,6 +665,11 @@ struct ecma119_image
     int num_bootsrc;
     IsoFileSrc **bootsrc; /* location of the boot images in the new image */
 
+    int *boot_appended_idx; /* Appended partition which serve as boot images */
+
+    uint32_t *boot_intvl_start;   /* In blocks of 2048 bytes */
+    uint32_t *boot_intvl_size;    /* In blocks of  512 bytes */
+
     /*
      * System Area related information
      */
@@ -821,6 +851,11 @@ struct ecma119_image
     /* Whether the eventual backup GPT is not part of the ISO filesystem */
     int gpt_backup_outside;
 
+    /* The base UUID for the generated GPT UUIDs */
+    uint8_t gpt_uuid_base[16];
+    /* The counter which distinguishes the GPT UUIDs */
+    uint32_t gpt_uuid_counter;
+
     uint32_t efi_boot_part_size;
     IsoFileSrc *efi_boot_part_filesrc; /* Just a pointer. Do not free. */
 
