@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2007 Vreixo Formoso
- * Copyright (c) 2009 - 2015 Thomas Schmitt
+ * Copyright (c) 2009 - 2016 Thomas Schmitt
  *
  * This file is part of the libisofs project; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License version 2 
@@ -157,7 +157,7 @@ int iso_init_with_flag(int flag)
 #ifdef Libisofs_with_libjtE
 
  /* Ugly compile time check for header version compatibility.
-    If everthing matches, then it produces no C code. In case of mismatch,
+    If everything matches, then it produces no C code. In case of mismatch,
     intentionally faulty C code will be inserted.
  */ 
  /* The indendation is an advise of man gcc to help old compilers ignoring */
@@ -380,7 +380,7 @@ const char *iso_error_to_msg(int errcode)
     case ISO_DATA_SOURCE_MISHAP:
     case ISO_DATA_SOURCE_FAILURE:
     case ISO_DATA_SOURCE_FATAL:
-        return "Read error occured with IsoDataSource";
+        return "Read error occurred with IsoDataSource";
     case ISO_AAIP_IGNORED:
         return "AAIP info with ACL or xattr in ISO image will be ignored";
     case ISO_AAIP_BAD_ACL:
@@ -543,6 +543,10 @@ const char *iso_error_to_msg(int errcode)
         return "A general note message was issued";
     case ISO_BAD_FSRC_FILETYPE:
         return "Unrecognized file type of IsoFileSrc object";
+    case ISO_GPT_NO_VOL_UUID:
+        return "Cannot derive GPT GUID from undefined pseudo-UUID volume timestamp";
+    case ISO_BAD_GPT_GUID_MODE:
+        return "Unrecognized GPT disk GUID setup mode";
     default:
         return "Unknown error";
     }
